@@ -1,4 +1,4 @@
-// Copyright (C)  2012-2015   Mark Seligman
+// Copyright (C)  2012-2016   Mark Seligman
 //
 // This file is part of ArboristBridgeR.
 //
@@ -28,9 +28,10 @@
 
 class CallBack {
  public:
-  static void SampleRows(int samp[]);
-  static void QSortI(int ySorted[], int rank2Row[], int one, int nRow);
-  static void QSortD(double ySorted[], int rank2Row[], int one, int nRow);
+  static void SampleInit(unsigned int _nRow, double _sampleWeight[], bool _withRepl);
+  static void SampleRows(unsigned int nSamp, int out[]);
+  static void QSortI(int ySorted[],  int rank2Row[], int one,  int nRow);
+  static void QSortD(double ySorted[],  int rank2Row[], int one,  int nRow);
   static void RUnif(int len, double out[]);
 };
 
